@@ -1,18 +1,8 @@
 #ifndef AWS_TESTING_AWS_TEST_HARNESS_H
 #define AWS_TESTING_AWS_TEST_HARNESS_H
-/*
- * Copyright 2010-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
- *
- * Licensed under the Apache License, Version 2.0 (the "License").
- * You may not use this file except in compliance with the License.
- * A copy of the License is located at
- *
- *  http://aws.amazon.com/apache2.0
- *
- * or in the "license" file accompanying this file. This file is distributed
- * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
- * express or implied. See the License for the specific language governing
- * permissions and limitations under the License.
+/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
  */
 
 #include <aws/common/common.h>
@@ -390,6 +380,15 @@ static inline int s_aws_run_test_case(struct aws_test_harness *harness) {
 
 #if defined(_WIN32)
     SetUnhandledExceptionFilter(s_test_print_stack_trace);
+    /* Set working directory to path to this exe */
+    char cwd[512];
+    DWORD len = GetModuleFileNameA(NULL, cwd, sizeof(cwd));
+    DWORD idx = len - 1;
+    while (idx && cwd[idx] != '\\') {
+        idx--;
+    }
+    cwd[idx] = 0;
+    SetCurrentDirectory(cwd);
 #elif defined(AWS_HAVE_EXECINFO)
     struct sigaction sa;
     memset(&sa, 0, sizeof(struct sigaction));
